@@ -1,16 +1,20 @@
 /*
- * Copyright (c) 2008-2024 Jonathan Schleifer <js@nil.im>
+ * Copyright (c) 2008-2025 Jonathan Schleifer <js@nil.im>
  *
  * All rights reserved.
  *
- * This file is part of ObjFW. It may be distributed under the terms of the
- * Q Public License 1.0, which can be found in the file LICENSE.QPL included in
- * the packaging of this file.
+ * This program is free software: you can redistribute it and/or modify it
+ * under the terms of the GNU Lesser General Public License version 3.0 only,
+ * as published by the Free Software Foundation.
  *
- * Alternatively, it may be distributed under the terms of the GNU General
- * Public License, either version 2 or 3, which can be found in the file
- * LICENSE.GPLv2 or LICENSE.GPLv3 respectively included in the packaging of this
- * file.
+ * This program is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+ * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
+ * version 3.0 for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public License
+ * version 3.0 along with this program. If not, see
+ * <https://www.gnu.org/licenses/>.
  */
 
 #import "OFObject.h"
@@ -49,7 +53,7 @@ typedef enum {
 } OFHTTPRequestMethod;
 
 /**
- * @struct OFHTTPRequestProtocolVersion OFHTTPRequest.h ObjFW/OFHTTPRequest.h
+ * @struct OFHTTPRequestProtocolVersion OFHTTPRequest.h ObjFW/ObjFW.h
  *
  * @brief The HTTP version of the HTTP request.
  */
@@ -61,7 +65,7 @@ typedef struct OF_BOXABLE OFHTTPRequestProtocolVersion {
 } OFHTTPRequestProtocolVersion;
 
 /**
- * @class OFHTTPRequest OFHTTPRequest.h ObjFW/OFHTTPRequest.h
+ * @class OFHTTPRequest OFHTTPRequest.h ObjFW/ObjFW.h
  *
  * @brief A class for storing HTTP requests.
  */
@@ -140,12 +144,12 @@ OF_SUBCLASSING_RESTRICTED
 extern "C" {
 #endif
 /**
- * @brief Returns a C string describing the specified request method.
+ * @brief Returns a string describing the specified request method.
  *
- * @param method The request method which should be described as a C string
- * @return A C string describing the specified request method
+ * @param method The request method which should be described as a string
+ * @return A string describing the specified request method
  */
-extern const char *_Nullable OFHTTPRequestMethodName(
+extern OFString *_Nullable OFHTTPRequestMethodString(
     OFHTTPRequestMethod method);
 
 /**
@@ -156,7 +160,31 @@ extern const char *_Nullable OFHTTPRequestMethodName(
  * @throw OFInvalidFormatException The specified string is not a valid HTTP
  *				   request method
  */
-extern OFHTTPRequestMethod OFHTTPRequestMethodParseName(OFString *string);
+extern OFHTTPRequestMethod OFHTTPRequestMethodParseString(OFString *string);
+
+/**
+ * @brief Returns a C string describing the specified request method.
+ *
+ * @deprecated Use @ref OFHTTPRequestMethodString instead.
+ *
+ * @param method The request method which should be described as a C string
+ * @return A C string describing the specified request method
+ */
+extern const char *_Nullable OFHTTPRequestMethodName(OFHTTPRequestMethod method)
+    OF_DEPRECATED(ObjFW, 1, 1, "Use OFHTTPRequestMethodString instead");
+
+/**
+ * @brief Returns the request method for the specified string.
+ *
+ * @deprecated Use @ref OFHTTPRequestMethodParseString instead.
+ *
+ * @param string The string for which the request method should be returned
+ * @return The request method for the specified string
+ * @throw OFInvalidFormatException The specified string is not a valid HTTP
+ *				   request method
+ */
+extern OFHTTPRequestMethod OFHTTPRequestMethodParseName(OFString *string)
+    OF_DEPRECATED(ObjFW, 1, 1, "Use OFHTTPRequestMethodParseString instead");
 #ifdef __cplusplus
 }
 #endif
