@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2008-2024 Jonathan Schleifer <js@nil.im>
+ * Copyright (c) 2008-2025 Jonathan Schleifer <js@nil.im>
  *
  * All rights reserved.
  *
@@ -95,6 +95,10 @@ typedef enum {
 	OFStringEncodingKOI8R,
 	/** KOI8-U */
 	OFStringEncodingKOI8U,
+	/** Windows-1250 */
+	OFStringEncodingWindows1250,
+	/** Code page 852 */
+	OFStringEncodingCodepage852,
 	/** Try to automatically detect the encoding */
 	OFStringEncodingAutodetect = -1
 } OFStringEncoding;
@@ -131,7 +135,7 @@ typedef void (^OFStringLineEnumerationBlock)(OFString *line, bool *stop);
 #endif
 
 /**
- * @class OFString OFString.h ObjFW/OFString.h
+ * @class OFString OFString.h ObjFW/ObjFW.h
  *
  * @brief A class for handling strings.
  */
@@ -175,29 +179,113 @@ typedef void (^OFStringLineEnumerationBlock)(OFString *line, bool *stop);
  */
 @property (readonly, nonatomic) OFString *capitalizedString;
 
+/**
+ * @brief The decimal value of the string as a `char`.
+ *
+ * Leading and trailing whitespaces are ignored.
+ *
+ * @throw OFInvalidFormatException The string contains non-number characters
+ * @throw OFOutOfRangeException The value is too big or too small to fit into
+ *				a `char`
+ */
+@property (readonly, nonatomic) signed char charValue;
+
+/**
+ * @brief The decimal value of the string as a `short`.
+ *
+ * Leading and trailing whitespaces are ignored.
+ *
+ * @throw OFInvalidFormatException The string contains non-number characters
+ * @throw OFOutOfRangeException The value is too big or too small to fit into
+ *				a `short`
+ */
+@property (readonly, nonatomic) short shortValue;
+
+/**
+ * @brief The decimal value of the string as an `int`.
+ *
+ * Leading and trailing whitespaces are ignored.
+ *
+ * @throw OFInvalidFormatException The string contains non-number characters
+ * @throw OFOutOfRangeException The value is too big or too small to fit into
+ *				an `int`
+ */
+@property (readonly, nonatomic) int intValue;
+
+/**
+ * @brief The decimal value of the string as a `long`.
+ *
+ * Leading and trailing whitespaces are ignored.
+ *
+ * @throw OFInvalidFormatException The string contains non-number characters
+ * @throw OFOutOfRangeException The value is too big or too small to fit into
+ *				a `long`
+ */
+@property (readonly, nonatomic) long longValue;
+
 /**
  * @brief The decimal value of the string as a `long long`.
  *
  * Leading and trailing whitespaces are ignored.
  *
- * If the string contains any non-number characters, an
- * @ref OFInvalidFormatException is thrown.
- *
- * If the number is too big to fit into a `long long`, an
- * @ref OFOutOfRangeException is thrown.
+ * @throw OFInvalidFormatException The string contains non-number characters
+ * @throw OFOutOfRangeException The value is too big or too small to fit into
+ *				a `long long`
  */
 @property (readonly, nonatomic) long long longLongValue;
 
+/**
+ * @brief The decimal value of the string as an `unsigned char`.
+ *
+ * Leading and trailing whitespaces are ignored.
+ *
+ * @throw OFInvalidFormatException The string contains non-number characters
+ * @throw OFOutOfRangeException The value is too big to fit into an
+ *				`unsigned char`
+ */
+@property (readonly, nonatomic) unsigned char unsignedCharValue;
+
+/**
+ * @brief The decimal value of the string as an `unsigned short`.
+ *
+ * Leading and trailing whitespaces are ignored.
+ *
+ * @throw OFInvalidFormatException The string contains non-number characters
+ * @throw OFOutOfRangeException The value is too big to fit into an
+ *				`unsigned short`
+ */
+@property (readonly, nonatomic) unsigned short unsignedShortValue;
+
+/**
+ * @brief The decimal value of the string as an `unsigned int`.
+ *
+ * Leading and trailing whitespaces are ignored.
+ *
+ * @throw OFInvalidFormatException The string contains non-number characters
+ * @throw OFOutOfRangeException The value is too big to fit into an
+ *				`unsigned int`
+ */
+@property (readonly, nonatomic) unsigned int unsignedIntValue;
+
+/**
+ * @brief The decimal value of the string as an `unsigned long`.
+ *
+ * Leading and trailing whitespaces are ignored.
+ *
+ * @throw OFInvalidFormatException The string contains non-number characters
+ * @throw OFOutOfRangeException The value is too big to fit into an
+ *				`unsigned long`
+ */
+@property (readonly, nonatomic) unsigned long unsignedLongValue;
+
 /**
  * @brief The decimal value of the string as an `unsigned long long`.
  *
  * Leading and trailing whitespaces are ignored.
  *
- * If the string contains any non-number characters, an
- * @ref OFInvalidFormatException is thrown.
- *
- * If the number is too big to fit into an `unsigned long long`, an
- * @ref OFOutOfRangeException is thrown.
+ * @throw OFInvalidFormatException The string contains non-number characters
+ * @throw OFOutOfRangeException The value is too big to fit into an
+ *				`unsigned long long`
  */
 @property (readonly, nonatomic) unsigned long long unsignedLongLongValue;
 
@@ -919,6 +1007,19 @@ typedef void (^OFStringLineEnumerationBlock)(OFString *line, bool *stop);
  */
 - (const char *)lossyCStringWithEncoding: (OFStringEncoding)encoding;
 
+/**
+ * @brief Returns the OFString as an insecure C string (meaning it can contain
+ *	  `\0`) in the specified encoding.
+ *
+ * The result is valid until the autorelease pool is released. If you want to
+ * use the result outside the scope of the current autorelease pool, you have to
+ * copy it.
+ *
+ * @param encoding The encoding for the C string
+ * @return The OFString as a C string in the specified encoding
+ */
+- (const char *)insecureCStringWithEncoding: (OFStringEncoding)encoding;
+
 /**
  * @brief Returns the number of bytes the string needs in the specified
  *	  encoding.
@@ -996,6 +1097,39 @@ typedef void (^OFStringLineEnumerationBlock)(OFString *line, bool *stop);
 		 options: (OFStringSearchOptions)options
 		   range: (OFRange)range;
 
+/**
+ * @brief Returns the range of the first character from the set.
+ *
+ * @param characterSet The set of characters to search for
+ * @return The range of the first occurrence of a character from the set or a
+ *	   range with `OFNotFound` as start position if it was not found
+ */
+- (OFRange)rangeOfCharacterFromSet: (OFCharacterSet *)characterSet;
+
+/**
+ * @brief Returns the range of the first character from the set.
+ *
+ * @param characterSet The set of characters to search for
+ * @param options Options modifying search behavior
+ * @return The range of the first occurrence of a character from the set or a
+ *	   range with `OFNotFound` as start position if it was not found
+ */
+- (OFRange)rangeOfCharacterFromSet: (OFCharacterSet *)characterSet
+			   options: (OFStringSearchOptions)options;
+
+/**
+ * @brief Returns the index of the first character from the set.
+ *
+ * @param characterSet The set of characters to search for
+ * @param options Options modifying search behavior
+ * @param range The range in which to search
+ * @return The range of the first occurrence of a character from the set or a
+ *	   range with `OFNotFound` as start position if it was not found
+ */
+- (OFRange)rangeOfCharacterFromSet: (OFCharacterSet *)characterSet
+			   options: (OFStringSearchOptions)options
+			     range: (OFRange)range;
+
 /**
  * @brief Returns the index of the first character from the set.
  *
@@ -1003,7 +1137,8 @@ typedef void (^OFStringLineEnumerationBlock)(OFString *line, bool *stop);
  * @return The index of the first occurrence of a character from the set or
  *	   `OFNotFound` if it was not found
  */
-- (size_t)indexOfCharacterFromSet: (OFCharacterSet *)characterSet;
+- (size_t)indexOfCharacterFromSet: (OFCharacterSet *)characterSet
+    OF_DEPRECATED(ObjFW, 1, 3, "Use -[rangeOfCharacterFromSet:] instead");
 
 /**
  * @brief Returns the index of the first character from the set.
@@ -1014,7 +1149,9 @@ typedef void (^OFStringLineEnumerationBlock)(OFString *line, bool *stop);
  *	   `OFNotFound` if it was not found
  */
 - (size_t)indexOfCharacterFromSet: (OFCharacterSet *)characterSet
-			  options: (OFStringSearchOptions)options;
+			  options: (OFStringSearchOptions)options
+    OF_DEPRECATED(ObjFW, 1, 3,
+	"Use -[rangeOfCharacterFromSet:options:] instead");
 
 /**
  * @brief Returns the index of the first character from the set.
@@ -1027,7 +1164,9 @@ typedef void (^OFStringLineEnumerationBlock)(OFString *line, bool *stop);
  */
 - (size_t)indexOfCharacterFromSet: (OFCharacterSet *)characterSet
 			  options: (OFStringSearchOptions)options
-			    range: (OFRange)range;
+			    range: (OFRange)range
+    OF_DEPRECATED(ObjFW, 1, 3,
+	"Use -[rangeOfCharacterFromSet:options:range:] instead");
 
 /**
  * @brief Returns whether the string contains the specified string.
@@ -1062,46 +1201,162 @@ typedef void (^OFStringLineEnumerationBlock)(OFString *line, bool *stop);
 - (OFString *)substringWithRange: (OFRange)range;
 
 /**
- * @brief The value of the string in the specified base as a `long long`.
+ * @brief The value of the string in the specified base as a `char`.
  *
  * Leading and trailing whitespaces are ignored.
  *
- * If the string contains any non-number characters, an
- * @ref OFInvalidFormatException is thrown.
- *
- * If the number is too big to fit into a `long long`, an
- * @ref OFOutOfRangeException is thrown.
- *
  * @param base The base to use. If the base is 0, base 16 is assumed if the
  * 	       string starts with 0x (after stripping white spaces). If the
  * 	       string starts with 0, base 8 is assumed. Otherwise, base 10 is
  * 	       assumed.
  * @return The value of the string in the specified base
- * @throw OFInvalidFormatException The string cannot be parsed as a `long long`
- * @throw OFOutOfRangeException The value cannot be represented as a `long long`
+ * @throw OFInvalidFormatException The string contains non-number characters
+ * @throw OFOutOfRangeException The value is too big or too small to fit into
+ *				a `char`
+ */
+- (signed char)charValueWithBase: (unsigned char)base;
+
+/**
+ * @brief The value of the string in the specified base as a `short`.
+ *
+ * Leading and trailing whitespaces are ignored.
+ *
+ * @param base The base to use. If the base is 0, base 16 is assumed if the
+ * 	       string starts with 0x (after stripping white spaces). If the
+ * 	       string starts with 0, base 8 is assumed. Otherwise, base 10 is
+ * 	       assumed.
+ * @return The value of the string in the specified base
+ * @throw OFInvalidFormatException The string contains non-number characters
+ * @throw OFOutOfRangeException The value is too big or too small to fit into
+ *				a `short`
+ */
+- (short)shortValueWithBase: (unsigned char)base;
+
+/**
+ * @brief The value of the string in the specified base as an `int`.
+ *
+ * Leading and trailing whitespaces are ignored.
+ *
+ * @param base The base to use. If the base is 0, base 16 is assumed if the
+ * 	       string starts with 0x (after stripping white spaces). If the
+ * 	       string starts with 0, base 8 is assumed. Otherwise, base 10 is
+ * 	       assumed.
+ * @return The value of the string in the specified base
+ * @throw OFInvalidFormatException The string contains non-number characters
+ * @throw OFOutOfRangeException The value is too big or too small to fit into
+ *				an `int`
+ */
+- (int)intValueWithBase: (unsigned char)base;
+
+/**
+ * @brief The value of the string in the specified base as a `long`.
+ *
+ * Leading and trailing whitespaces are ignored.
+ *
+ * @param base The base to use. If the base is 0, base 16 is assumed if the
+ * 	       string starts with 0x (after stripping white spaces). If the
+ * 	       string starts with 0, base 8 is assumed. Otherwise, base 10 is
+ * 	       assumed.
+ * @return The value of the string in the specified base
+ * @throw OFInvalidFormatException The string contains non-number characters
+ * @throw OFOutOfRangeException The value is too big or too small to fit into
+ *				a `long`
+ */
+- (long)longValueWithBase: (unsigned char)base;
+
+/**
+ * @brief The value of the string in the specified base as a `long long`.
+ *
+ * Leading and trailing whitespaces are ignored.
+ *
+ * @param base The base to use. If the base is 0, base 16 is assumed if the
+ * 	       string starts with 0x (after stripping white spaces). If the
+ * 	       string starts with 0, base 8 is assumed. Otherwise, base 10 is
+ * 	       assumed.
+ * @return The value of the string in the specified base
+ * @throw OFInvalidFormatException The string contains non-number characters
+ * @throw OFOutOfRangeException The value is too big or too small to fit into
+ *				a `long long`
  */
 - (long long)longLongValueWithBase: (unsigned char)base;
 
+/**
+ * @brief The value of the string in the specified base as an `unsigned char`.
+ *
+ * Leading and trailing whitespaces are ignored.
+ *
+ * @param base The base to use. If the base is 0, base 16 is assumed if the
+ * 	       string starts with 0x (after stripping white spaces). If the
+ * 	       string starts with 0, base 8 is assumed. Otherwise, base 10 is
+ * 	       assumed.
+ * @return The value of the string in the specified base
+ * @throw OFInvalidFormatException The string contains non-number characters
+ * @throw OFOutOfRangeException The value is too big to fit into an
+ *				`unsigned char`
+ */
+- (unsigned char)unsignedCharValueWithBase: (unsigned char)base;
+
+/**
+ * @brief The value of the string in the specified base as an `unsigned short`.
+ *
+ * Leading and trailing whitespaces are ignored.
+ *
+ * @param base The base to use. If the base is 0, base 16 is assumed if the
+ * 	       string starts with 0x (after stripping white spaces). If the
+ * 	       string starts with 0, base 8 is assumed. Otherwise, base 10 is
+ * 	       assumed.
+ * @return The value of the string in the specified base
+ * @throw OFInvalidFormatException The string contains non-number characters
+ * @throw OFOutOfRangeException The value is too big to fit into an
+ *				`unsigned short`
+ */
+- (unsigned short)unsignedShortValueWithBase: (unsigned char)base;
+
+/**
+ * @brief The value of the string in the specified base as an `unsigned int`.
+ *
+ * Leading and trailing whitespaces are ignored.
+ *
+ * @param base The base to use. If the base is 0, base 16 is assumed if the
+ * 	       string starts with 0x (after stripping white spaces). If the
+ * 	       string starts with 0, base 8 is assumed. Otherwise, base 10 is
+ * 	       assumed.
+ * @return The value of the string in the specified base
+ * @throw OFInvalidFormatException The string contains non-number characters
+ * @throw OFOutOfRangeException The value is too big to fit into an
+ *				`unsigned int`
+ */
+- (unsigned int)unsignedIntValueWithBase: (unsigned char)base;
+
+/**
+ * @brief The value of the string in the specified base as an `unsigned long`.
+ *
+ * Leading and trailing whitespaces are ignored.
+ *
+ * @param base The base to use. If the base is 0, base 16 is assumed if the
+ * 	       string starts with 0x (after stripping white spaces). If the
+ * 	       string starts with 0, base 8 is assumed. Otherwise, base 10 is
+ * 	       assumed.
+ * @return The value of the string in the specified base
+ * @throw OFInvalidFormatException The string contains non-number characters
+ * @throw OFOutOfRangeException The value is too big to fit into an
+ *				`unsigned long`
+ */
+- (unsigned long)unsignedLongValueWithBase: (unsigned char)base;
+
 /**
  * @brief The value of the string in the specified base as an
  *	  `unsigned long long`.
  *
  * Leading and trailing whitespaces are ignored.
  *
- * If the string contains any non-number characters, an
- * @ref OFInvalidFormatException is thrown.
- *
- * If the number is too big to fit into an `unsigned long long`, an
- * @ref OFOutOfRangeException is thrown.
- *
  * @param base The base to use. If the base is 0, base 16 is assumed if the
  * 	       string starts with 0x (after stripping white spaces). If the
  * 	       string starts with 0, base 8 is assumed. Otherwise, base 10 is
  * 	       assumed.
  * @return The value of the string in the specified base
- * @throw OFInvalidFormatException The string cannot be parsed as an
- *				   `unsigned long long`
- * @throw OFOutOfRangeException The value cannot be represented as an
+ * @throw OFInvalidFormatException The string contains non-number characters
+ * @throw OFOutOfRangeException The value is too big to fit into an
  *				`unsigned long long`
  */
 - (unsigned long long)unsignedLongLongValueWithBase: (unsigned char)base;
@@ -1350,11 +1605,6 @@ extern size_t OFUTF16StringLength(const OFChar16 *string);
  * @return The length of the specified UTF-32 string
  */
 extern size_t OFUTF32StringLength(const OFChar32 *string);
-
-extern char *_Nullable _OFStrDup(const char *_Nonnull) OF_VISIBILITY_HIDDEN;
-extern size_t _OFUTF8StringEncode(OFUnichar, char *) OF_VISIBILITY_HIDDEN;
-extern ssize_t _OFUTF8StringDecode(const char *, size_t, OFUnichar *)
-    OF_VISIBILITY_HIDDEN;
 #ifdef __cplusplus
 }
 #endif
